import pygame
from pygame.locals import *
import os
import sys
import random

from .toothpick import *

CONTINUE, NEW, EXIT = range(3)
MAIN_COLOR = (228, 0, 127)
INVALID_COLOR = (128, 128, 128)

class Title():
    scroll_speed = 3

    def __init__(self):
        # 背景画像
        self.bg = load_image("resources/image/bg", "title.png")
        self.wave = load_image("resources/image/bg", "wave.png", -1)
        self.bgx = 0
        self.scr_width = pygame.display.get_surface().get_width()

        # スプライト
        self.all = pygame.sprite.RenderUpdates()
        Mimi.containers = self.all

        self.reset()
    
    def update(self):
        self.frame += 1
        self.bgx = (self.bgx - self.scroll_speed) % self.scr_width
        self.cursor.update()
        self.all.update()

        if self.frame % 600 == 0:
            self.create_mimi()
    
    def draw(self, screen):
        screen.blit(self.bg, (0, 0))
        screen.blit(self.wave, (self.bgx, 440))
        screen.blit(self.wave, (self.bgx - self.scr_width, 440))

        screen.blit(self.title, (40, 40))
        screen.blit(self.version, (320, 80))
        screen.blit(self.credit, (self.scr_width / 2 - self.credit.get_width() / 2, 490))

        self.all.draw(screen)

        if self.pressed == False:
            # 点滅
            if int(self.frame / 48 % 2) == 0:
                screen.blit(self.press_txt, (120, 230))
        else:
            screen.blit(self.continue_txt, (120, 150))
            screen.blit(self.new_txt, (120, 230))
            screen.blit(self.exit_txt, (120, 310))
            self.cursor.draw(screen)
    
    def reset(self):
        self.frame = 0
        self.pressed = False

        # セーブデータの有無を確認
        if os.path.exists("data/save.dat") == True:
            self.valid = True
        else:
            self.valid = False
        
        # フォント
        title_font = pygame.font.Font("resources/font/kirieji04.ttf", 80)
        menu_font = pygame.font.Font("resources/font/kirieji04.ttf", 40)
        sysfont = pygame.font.SysFont(None, 36)
        self.title = title_font.render(u"耳農場", True, MAIN_COLOR)
        self.version = menu_font.render("- Tropical Version -", True, MAIN_COLOR)
        self.press_txt = menu_font.render("Press SPACE", True, MAIN_COLOR)
        if self.valid == True:
            self.select = CONTINUE
            self.continue_txt = menu_font.render("CONTINUE", True, MAIN_COLOR)
        elif self.valid == False:
            self.select = NEW
            self.continue_txt = menu_font.render("CONTINUE", True, INVALID_COLOR)
        self.new_txt = menu_font.render("NEW GAME", True, MAIN_COLOR)
        self.exit_txt = menu_font.render("EXIT", True, MAIN_COLOR)
        self.credit = sysfont.render("Jizo Games", True, (255, 255, 255))

        # カーソル
        self.cursor = Cursor((70, 160 + self.select * 80), 0, MAIN_COLOR)

        # スプライト
        self.all.empty()
        self.create_mimi()
    
    def cursor_set(self):
        self.cursor.set_pos((70, 160 + self.select * 80))
    
    def create_mimi(self):
        if len(self.all) <= 15:
            Mimi()

class Mimi(pygame.sprite.Sprite):
    SPEED = 1

    def __init__(self):
        super().__init__(self.containers)
        self.image = load_image("resources/image/mimi", "normal_mimi.png", -1)
        self.rect = self.image.get_rect()
        randx = random.randint(0, 50)
        randy = random.randint(0, 50)
        self.rect.center = (680 + randx, 130 + randy)
        self.alpha = 0
        self.image.set_alpha(self.alpha)
        self.grow = True
    
    def update(self):
        if self.grow == True:
            self.alpha += 5
            if self.alpha >= 255:
                self.grow = False
            self.image.set_alpha(self.alpha)
        elif self.grow == False:
            if self.rect.centery < 440:
                self.rect.move_ip(0, self.SPEED)
            elif self.rect.centery == 440:
                self.image = pygame.transform.rotate(self.image, -60)
                self.rect.move_ip(0, self.SPEED)
            else:
                self.rect.move_ip(-self.SPEED * 2, 0)
            if self.rect.right < 0:
                self.kill()

