import pygame
from pygame.locals import *
import os

class Cursor():
    MOVE_RANGE = 15
    SPEED = 1

    def __init__(self, pos, direction, color=(255, 255, 255)):
        self.direction = direction
        self.color = color
        self.set_pos(pos)
    
    def update(self):
        if self.direction == 0 or self.direction == 1:
            self.x += self.SPEED
            if self.x < self.left or self.x > self.right:
                self.SPEED = -self.SPEED
        elif self.direction == 2 or self.direction == 3:
            self.y += self.SPEED
            if self.y < self.top or self.y > self.bottom:
                self.SPEED = -self.SPEED
    
    def draw(self, screen):
        if self.direction == 0:
            pygame.draw.polygon(screen, self.color, ([self.x, self.y], [self.x, self.y + 20], [self.x + 20, self.y + 10]))
        elif self.direction == 1:
            pygame.draw.polygon(screen, self.color, ([self.x, self.y], [self.x, self.y + 20], [self.x - 20, self.y + 10]))
        elif self.direction == 2:
            pygame.draw.polygon(screen, self.color, ([self.x, self.y], [self.x + 20, self.y], [self.x + 10, self.y - 20]))
        elif self.direction == 3:
            pygame.draw.polygon(screen, self.color, ([self.x, self.y], [self.x + 20, self.y], [self.x + 10, self.y + 20]))
    
    def set_pos(self, pos):
        self.x, self.y = pos
        if self.direction == 0 or self.direction == 1:
            self.left = self.x - self.MOVE_RANGE
            self.right = self.x
        elif self.direction == 2 or self.direction == 3:
            self.top = self.y
            self.bottom = self.y + self.MOVE_RANGE
    
    def set_color(self, color):
        self.color = color

def load_image(dir, filename, colorkey=None):
    file = os.path.join(dir, filename)
    image = pygame.image.load(file)
    image = image.convert()
    if not colorkey == None:
        if colorkey == -1:
            colorkey = image.get_at((0, 0))
        image.set_colorkey(colorkey, RLEACCEL)
    return image

def split_image(image, n, m):
    image_list = []
    w = image.get_width()
    h = image.get_height()
    w1 = int(w / n)
    h1 = int(h / m)
    for i in range(0, h, h1):
        for j in range(0, w, w1):
            surface = pygame.Surface((w1, h1))
            surface.blit(image, (0, 0), (j, i, w1, h1))
            surface.set_colorkey(surface.get_at((0, 0)), RLEACCEL)
            surface.convert()
            image_list.append(surface)
    return image_list

def play_bgm(filename):
    bgm_file = os.path.join("resources/music", filename)
    pygame.mixer.music.load(bgm_file)
    pygame.mixer.music.play(-1)